Struct TaskContext

pub struct TaskContext<S>
where S: TaskStore + Send + Sync + Clone + 'static,
{ /* private fields */ }

Implementations

Source

impl<S> TaskContext<S>
where S: TaskStore + Send + Sync + Clone + 'static,

pub fn new(store: S) -> Self

Creates a new TaskContext with the provided store.

Examples found in repository?
examples/basic.rs (line 18)
12async fn main() {
13    tracing_subscriber::fmt()
14        .with_max_level(tracing::Level::INFO)
15        .init();
16
17    let task_store = InMemoryTaskStore::new();
18    let context = TaskContext::new(task_store)
19        .register::<MyTask1>()
20        .register::<MyTask2>()
21        .set_concurrency("default", 10)
22        .start_with_cleaner()
23        .await;
24    let mut tasks = Vec::new();
25    for _ in 0..100 {
26        tasks.push(TaskConfiguration {
27            inner: MyTask1::new("name1".to_string(), 32),
28            kind: TaskKind::Once,
29            delay_seconds: None,
30        });
31    }
32
33    tokio::spawn(async move {
34        context.add_tasks(tasks).await.unwrap();
35    });
36    tokio::time::sleep(Duration::from_secs(20)).await;
37    
38}
More examples
Hide additional examples
examples/nativedb.rs (line 22)
15async fn main() {
16    tracing_subscriber::fmt()
17        .with_max_level(tracing::Level::INFO)
18        .init();
19
20    let task_store = NativeDbTaskStore::default();
21    task_store.restore_tasks().await.unwrap();
22    let context = TaskContext::new(task_store)
23        .register::<MyTask1>()
24        .register::<MyTask2>()
25        .set_concurrency("default", 10)
26        .start_with_cleaner()
27        .await;
28    let context = Arc::new(context);
29    let mut tasks = Vec::new();
30
31    for _ in 0..10000 {
32        tasks.push(TaskConfiguration {
33            inner: MyTask1::new("name1".to_string(), 32),
34            kind: TaskKind::Once,
35            delay_seconds: None,
36        });
37    }
38
39    tokio::spawn(async move {
40        context.add_tasks(tasks).await.unwrap();
41    });
42
43    tokio::time::sleep(Duration::from_secs(10000)).await;
44}
pub fn with_arc_store(store: Arc<S>) -> Self

Creates a new TaskContext with the provided Arc-wrapped store.

pub fn register<T>(self) -> Self
where T: Task,

Registers a new task type in the context.

Examples found in repository?
examples/basic.rs (line 19)
12async fn main() {
13    tracing_subscriber::fmt()
14        .with_max_level(tracing::Level::INFO)
15        .init();
16
17    let task_store = InMemoryTaskStore::new();
18    let context = TaskContext::new(task_store)
19        .register::<MyTask1>()
20        .register::<MyTask2>()
21        .set_concurrency("default", 10)
22        .start_with_cleaner()
23        .await;
24    let mut tasks = Vec::new();
25    for _ in 0..100 {
26        tasks.push(TaskConfiguration {
27            inner: MyTask1::new("name1".to_string(), 32),
28            kind: TaskKind::Once,
29            delay_seconds: None,
30        });
31    }
32
33    tokio::spawn(async move {
34        context.add_tasks(tasks).await.unwrap();
35    });
36    tokio::time::sleep(Duration::from_secs(20)).await;
37    
38}
More examples
Hide additional examples
examples/nativedb.rs (line 23)
15async fn main() {
16    tracing_subscriber::fmt()
17        .with_max_level(tracing::Level::INFO)
18        .init();
19
20    let task_store = NativeDbTaskStore::default();
21    task_store.restore_tasks().await.unwrap();
22    let context = TaskContext::new(task_store)
23        .register::<MyTask1>()
24        .register::<MyTask2>()
25        .set_concurrency("default", 10)
26        .start_with_cleaner()
27        .await;
28    let context = Arc::new(context);
29    let mut tasks = Vec::new();
30
31    for _ in 0..10000 {
32        tasks.push(TaskConfiguration {
33            inner: MyTask1::new("name1".to_string(), 32),
34            kind: TaskKind::Once,
35            delay_seconds: None,
36        });
37    }
38
39    tokio::spawn(async move {
40        context.add_tasks(tasks).await.unwrap();
41    });
42
43    tokio::time::sleep(Duration::from_secs(10000)).await;
44}
pub fn set_concurrency(self, queue: &str, count: usize) -> Self

Sets the concurrency level for a specified queue.

Examples found in repository?
examples/basic.rs (line 21)
12async fn main() {
13    tracing_subscriber::fmt()
14        .with_max_level(tracing::Level::INFO)
15        .init();
16
17    let task_store = InMemoryTaskStore::new();
18    let context = TaskContext::new(task_store)
19        .register::<MyTask1>()
20        .register::<MyTask2>()
21        .set_concurrency("default", 10)
22        .start_with_cleaner()
23        .await;
24    let mut tasks = Vec::new();
25    for _ in 0..100 {
26        tasks.push(TaskConfiguration {
27            inner: MyTask1::new("name1".to_string(), 32),
28            kind: TaskKind::Once,
29            delay_seconds: None,
30        });
31    }
32
33    tokio::spawn(async move {
34        context.add_tasks(tasks).await.unwrap();
35    });
36    tokio::time::sleep(Duration::from_secs(20)).await;
37    
38}
More examples
Hide additional examples
examples/nativedb.rs (line 25)
15async fn main() {
16    tracing_subscriber::fmt()
17        .with_max_level(tracing::Level::INFO)
18        .init();
19
20    let task_store = NativeDbTaskStore::default();
21    task_store.restore_tasks().await.unwrap();
22    let context = TaskContext::new(task_store)
23        .register::<MyTask1>()
24        .register::<MyTask2>()
25        .set_concurrency("default", 10)
26        .start_with_cleaner()
27        .await;
28    let context = Arc::new(context);
29    let mut tasks = Vec::new();
30
31    for _ in 0..10000 {
32        tasks.push(TaskConfiguration {
33            inner: MyTask1::new("name1".to_string(), 32),
34            kind: TaskKind::Once,
35            delay_seconds: None,
36        });
37    }
38
39    tokio::spawn(async move {
40        context.add_tasks(tasks).await.unwrap();
41    });
42
43    tokio::time::sleep(Duration::from_secs(10000)).await;
44}
pub async fn start(self) -> Self

Starts the task context with workers, leaving task cleanup to be handled manually by the user.

pub async fn start_with_cleaner(self) -> Self

Runs the task context, enabling workers and the task cleaner.

Examples found in repository?
examples/basic.rs (line 22)
12async fn main() {
13    tracing_subscriber::fmt()
14        .with_max_level(tracing::Level::INFO)
15        .init();
16
17    let task_store = InMemoryTaskStore::new();
18    let context = TaskContext::new(task_store)
19        .register::<MyTask1>()
20        .register::<MyTask2>()
21        .set_concurrency("default", 10)
22        .start_with_cleaner()
23        .await;
24    let mut tasks = Vec::new();
25    for _ in 0..100 {
26        tasks.push(TaskConfiguration {
27            inner: MyTask1::new("name1".to_string(), 32),
28            kind: TaskKind::Once,
29            delay_seconds: None,
30        });
31    }
32
33    tokio::spawn(async move {
34        context.add_tasks(tasks).await.unwrap();
35    });
36    tokio::time::sleep(Duration::from_secs(20)).await;
37    
38}
More examples
Hide additional examples
examples/nativedb.rs (line 26)
15async fn main() {
16    tracing_subscriber::fmt()
17        .with_max_level(tracing::Level::INFO)
18        .init();
19
20    let task_store = NativeDbTaskStore::default();
21    task_store.restore_tasks().await.unwrap();
22    let context = TaskContext::new(task_store)
23        .register::<MyTask1>()
24        .register::<MyTask2>()
25        .set_concurrency("default", 10)
26        .start_with_cleaner()
27        .await;
28    let context = Arc::new(context);
29    let mut tasks = Vec::new();
30
31    for _ in 0..10000 {
32        tasks.push(TaskConfiguration {
33            inner: MyTask1::new("name1".to_string(), 32),
34            kind: TaskKind::Once,
35            delay_seconds: None,
36        });
37    }
38
39    tokio::spawn(async move {
40        context.add_tasks(tasks).await.unwrap();
41    });
42
43    tokio::time::sleep(Duration::from_secs(10000)).await;
44}
pub async fn add_task<T>( &self, task: T, kind: TaskKind, delay_seconds: Option<u32>, ) -> Result<(), String>
where T: Task + Send + Sync + 'static,

Adds a new task to the context for execution.

pub async fn add_tasks<T>( &self, tasks: Vec<TaskConfiguration<T>>, ) -> Result<(), String>
where T: Task + Send + Sync + 'static,

Adds a new task to the context for execution.

Examples found in repository?
examples/basic.rs (line 34)
12async fn main() {
13    tracing_subscriber::fmt()
14        .with_max_level(tracing::Level::INFO)
15        .init();
16
17    let task_store = InMemoryTaskStore::new();
18    let context = TaskContext::new(task_store)
19        .register::<MyTask1>()
20        .register::<MyTask2>()
21        .set_concurrency("default", 10)
22        .start_with_cleaner()
23        .await;
24    let mut tasks = Vec::new();
25    for _ in 0..100 {
26        tasks.push(TaskConfiguration {
27            inner: MyTask1::new("name1".to_string(), 32),
28            kind: TaskKind::Once,
29            delay_seconds: None,
30        });
31    }
32
33    tokio::spawn(async move {
34        context.add_tasks(tasks).await.unwrap();
35    });
36    tokio::time::sleep(Duration::from_secs(20)).await;
37    
38}
More examples
Hide additional examples
examples/nativedb.rs (line 40)
15async fn main() {
16    tracing_subscriber::fmt()
17        .with_max_level(tracing::Level::INFO)
18        .init();
19
20    let task_store = NativeDbTaskStore::default();
21    task_store.restore_tasks().await.unwrap();
22    let context = TaskContext::new(task_store)
23        .register::<MyTask1>()
24        .register::<MyTask2>()
25        .set_concurrency("default", 10)
26        .start_with_cleaner()
27        .await;
28    let context = Arc::new(context);
29    let mut tasks = Vec::new();
30
31    for _ in 0..10000 {
32        tasks.push(TaskConfiguration {
33            inner: MyTask1::new("name1".to_string(), 32),
34            kind: TaskKind::Once,
35            delay_seconds: None,
36        });
37    }
38
39    tokio::spawn(async move {
40        context.add_tasks(tasks).await.unwrap();
41    });
42
43    tokio::time::sleep(Duration::from_secs(10000)).await;
44}