Struct PeriodicTask

pub struct PeriodicTask { /* private fields */ }

Implementations

Source

impl PeriodicTask

pub fn new(name: &str) -> Self

Creates a new instance of PeriodicTask.

Arguments
  • name: A string slice that holds the name of the task.
Returns

Returns a new instance of PeriodicTask.

Examples found in repository?
examples/periodic.rs (line 27)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    #[derive(Debug)]
    struct Test {
        pub name: String,
        pub age: u32,
    }

    let param = Arc::new(Test {
        name: "this is a test name".to_string(),
        age: 34,
    });
    let task = Arc::new(move |param: Option<Arc<Test>>| {
        Box::pin(async move {
            println!("this is periodic task. param={:#?}", param.unwrap());
            Ok(())
        })
    });
    let periodic_task = Arc::new(PeriodicTask::new("periodic example"));
    periodic_task.start_with_signal(task, Some(param), Duration::from_secs(2));
    tokio::time::sleep(Duration::from_secs(10 * 60)).await;
}
pub async fn shutdown(self: Arc<Self>)

Sends a shutdown signal to the task.

This method notifies the task to stop executing.

pub fn start_with_signal<F, P>( self: Arc<Self>, task: Arc<dyn Fn(Option<Arc<P>>) -> F + Send + Sync>, param: Option<Arc<P>>, interval: Duration, )
where F: Future<Output = Result<(), BoxError>> + Send + 'static, P: Send + Sync + 'static,

Starts the periodic task and sets up a signal handler for shutdown.

Arguments
  • task: An Arc of a function that returns a future to be executed periodically.
  • interval: A Duration specifying how often the task should run.
Type Parameters
  • F: The type of the future returned by the task function.
Requirements

The future must output a Result with a unit value or a BoxError on failure.

Examples found in repository?
examples/periodic.rs (line 28)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    #[derive(Debug)]
    struct Test {
        pub name: String,
        pub age: u32,
    }

    let param = Arc::new(Test {
        name: "this is a test name".to_string(),
        age: 34,
    });
    let task = Arc::new(move |param: Option<Arc<Test>>| {
        Box::pin(async move {
            println!("this is periodic task. param={:#?}", param.unwrap());
            Ok(())
        })
    });
    let periodic_task = Arc::new(PeriodicTask::new("periodic example"));
    periodic_task.start_with_signal(task, Some(param), Duration::from_secs(2));
    tokio::time::sleep(Duration::from_secs(10 * 60)).await;
}