pub struct RetryPolicy {
pub strategy: RetryStrategy,
pub max_retries: Option<u32>,
}Expand description
Retry policy to define how and when jobs should be retried
Fields
strategy: RetryStrategyStrategy for retrying failed jobs
max_retries: Option<u32>Maximum number of retries or retry indefinitely
Implementations
Sourceimpl RetryPolicy
impl RetryPolicy
Sourcepub const fn linear(interval: u32, max_retries: Option<u32>) -> Self
pub const fn linear(interval: u32, max_retries: Option<u32>) -> Self
Create a new linear retry policy with a maximum number of retries
Sourcepub const fn exponential(base: u32, max_retries: Option<u32>) -> Self
pub const fn exponential(base: u32, max_retries: Option<u32>) -> Self
Create a new exponential retry policy with a maximum number of retries
pub fn wait_time(&self, retry_count: u32) -> u32