pub struct InMemoryTaskStore { /* private fields */ }Implementations
Sourceimpl InMemoryTaskStore
impl InMemoryTaskStore
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new instance of InMemoryTaskStore.
Examples found in repository?
examples/basic.rs (line 17)
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = InMemoryTaskStore::new();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.set_concurrency("default", 10)
.start()
.await;
let mut tasks = Vec::new();
for _ in 0..100 {
tasks.push(TaskConfiguration {
inner: MyTask1::new("name1".to_string(), 32),
kind: TaskKind::Once,
delay_seconds: None,
});
}
tokio::spawn(async move {
context.add_tasks(tasks).await.unwrap();
});
tokio::time::sleep(Duration::from_secs(20)).await;
}Trait Implementations
Sourceimpl Clone for InMemoryTaskStore
impl Clone for InMemoryTaskStore
Sourcefn clone(&self) -> InMemoryTaskStore
fn clone(&self) -> InMemoryTaskStore
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InMemoryTaskStore
impl Default for InMemoryTaskStore
Sourcefn default() -> InMemoryTaskStore
fn default() -> InMemoryTaskStore
Returns the “default value” for a type. Read more
Sourceimpl TaskStore for InMemoryTaskStore
impl TaskStore for InMemoryTaskStore
type Error = InMemoryTaskStoreError
Sourcefn restore_tasks<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn restore_tasks<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Restores task states by cleaning up all tasks in a running state and handling their next run times. Read more
Sourcefn get<'life0, 'life1, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<TaskMeta>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get<'life0, 'life1, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<TaskMeta>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves task metadata based on the task ID. Read more
Sourcefn list<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TaskMeta>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TaskMeta>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Lists all task metadata. Read more
Sourcefn store_task<'life0, 'async_trait>(
&'life0 self,
task: TaskMeta,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn store_task<'life0, 'async_trait>(
&'life0 self,
task: TaskMeta,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Stores task metadata. Read more
Sourcefn store_tasks<'life0, 'async_trait>(
&'life0 self,
tasks: Vec<TaskMeta>,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn store_tasks<'life0, 'async_trait>(
&'life0 self,
tasks: Vec<TaskMeta>,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Stores tasks metadata. Read more
Sourcefn fetch_pending_tasks<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TaskMeta>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn fetch_pending_tasks<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<TaskMeta>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Fetches all pending tasks from the store. Read more
Sourcefn update_task_execution_status<'life0, 'life1, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
is_success: bool,
last_error: Option<String>,
next_run: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn update_task_execution_status<'life0, 'life1, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
is_success: bool,
last_error: Option<String>,
next_run: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Updates the execution status of a task. Read more
Sourcefn heartbeat<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
runner_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn heartbeat<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
runner_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Updates the heartbeat for a task. Read more
Sourcefn set_task_stopped<'life0, 'life1, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn set_task_stopped<'life0, 'life1, 'async_trait>(
&'life0 self,
task_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Marks a task as stopped. Read more