persistent_scheduler::core::context

Struct TaskContext

pub struct TaskContext<S>
where S: TaskStore,
{ /* private fields */ }

Implementations

Source

impl<S> TaskContext<S>
where S: TaskStore + Sync + Send + 'static,

pub fn new(store: S) -> Self

Creates a new TaskContext with the provided store.

Examples found in repository?
examples/basic.rs (line 18)
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = InMemoryTaskStore::new();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let mut tasks = Vec::new();
    for _ in 0..100000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
More examples
Hide additional examples
examples/nativedb.rs (line 22)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = NativeDbTaskStore::default();
    task_store.restore_tasks().await.unwrap();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let context = Arc::new(context);
    let mut tasks = Vec::new();

    for _ in 0..10000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    // context
    //     .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
    //     .await
    //     .unwrap();
    println!("添加结束了.");
    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
pub fn register<T>(self) -> Self
where T: Task,

Registers a new task type in the context.

Examples found in repository?
examples/basic.rs (line 19)
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = InMemoryTaskStore::new();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let mut tasks = Vec::new();
    for _ in 0..100000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
More examples
Hide additional examples
examples/nativedb.rs (line 23)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = NativeDbTaskStore::default();
    task_store.restore_tasks().await.unwrap();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let context = Arc::new(context);
    let mut tasks = Vec::new();

    for _ in 0..10000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    // context
    //     .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
    //     .await
    //     .unwrap();
    println!("添加结束了.");
    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
pub fn set_concurrency(self, queue: &str, count: u32) -> Self

Sets the concurrency level for a specified queue.

Examples found in repository?
examples/basic.rs (line 21)
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = InMemoryTaskStore::new();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let mut tasks = Vec::new();
    for _ in 0..100000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
More examples
Hide additional examples
examples/nativedb.rs (line 25)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = NativeDbTaskStore::default();
    task_store.restore_tasks().await.unwrap();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let context = Arc::new(context);
    let mut tasks = Vec::new();

    for _ in 0..10000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    // context
    //     .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
    //     .await
    //     .unwrap();
    println!("添加结束了.");
    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
pub fn start(self) -> Self

Starts the task context, including workers and the task cleaner.

Examples found in repository?
examples/basic.rs (line 22)
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = InMemoryTaskStore::new();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let mut tasks = Vec::new();
    for _ in 0..100000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
More examples
Hide additional examples
examples/nativedb.rs (line 26)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = NativeDbTaskStore::default();
    task_store.restore_tasks().await.unwrap();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let context = Arc::new(context);
    let mut tasks = Vec::new();

    for _ in 0..10000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    // context
    //     .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
    //     .await
    //     .unwrap();
    println!("添加结束了.");
    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
pub async fn add_task<T>( &self, task: T, delay_seconds: Option<u32>, ) -> Result<(), String>
where T: Task + Send + Sync + 'static,

Adds a new task to the context for execution.

pub async fn add_tasks<T>( &self, tasks: Vec<TaskAndDelay<T>>, ) -> Result<(), String>
where T: Task + Send + Sync + 'static,

Adds a new task to the context for execution.

Examples found in repository?
examples/basic.rs (line 32)
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = InMemoryTaskStore::new();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let mut tasks = Vec::new();
    for _ in 0..100000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    tokio::time::sleep(Duration::from_secs(100000000)).await;
}
More examples
Hide additional examples
examples/nativedb.rs (line 38)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
async fn main() {
    tracing_subscriber::fmt()
        .with_max_level(tracing::Level::INFO)
        .init();

    let task_store = NativeDbTaskStore::default();
    task_store.restore_tasks().await.unwrap();
    let context = TaskContext::new(task_store)
        .register::<MyTask1>()
        .register::<MyTask2>()
        .set_concurrency("default", 10)
        .start();
    let context = Arc::new(context);
    let mut tasks = Vec::new();

    for _ in 0..10000 {
        tasks.push(TaskAndDelay {
            inner: MyTask1::new("name1".to_string(), 32),
            delay_seconds: None,
        });
    }

    tokio::spawn(async move {
        context.add_tasks(tasks).await.unwrap();
    });

    // context
    //     .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
    //     .await
    //     .unwrap();
    println!("添加结束了.");
    tokio::time::sleep(Duration::from_secs(100000000)).await;
}