pub struct TaskContext<S>where
S: TaskStore,{ /* private fields */ }Implementations
Sourceimpl<S> TaskContext<S>
impl<S> TaskContext<S>
Sourcepub fn new(store: S) -> Self
pub fn new(store: S) -> Self
Creates a new TaskContext with the provided store.
Examples found in repository?
examples/basic.rs (line 18)
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = InMemoryTaskStore::new();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("name2".to_string(), 39), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}More examples
examples/nativedb.rs (line 22)
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = NativeDbTaskStore::default();
task_store.restore_tasks().await.unwrap();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.set_concurrency("default", 10)
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}Sourcepub fn register<T>(self) -> Selfwhere
T: Task,
pub fn register<T>(self) -> Selfwhere
T: Task,
Registers a new task type in the context.
Examples found in repository?
examples/basic.rs (line 19)
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = InMemoryTaskStore::new();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("name2".to_string(), 39), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}More examples
examples/nativedb.rs (line 23)
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = NativeDbTaskStore::default();
task_store.restore_tasks().await.unwrap();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.set_concurrency("default", 10)
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}Sourcepub fn set_concurrency(self, queue: &str, count: u32) -> Self
pub fn set_concurrency(self, queue: &str, count: u32) -> Self
Sets the concurrency level for a specified queue.
Examples found in repository?
examples/nativedb.rs (line 25)
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = NativeDbTaskStore::default();
task_store.restore_tasks().await.unwrap();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.set_concurrency("default", 10)
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}Sourcepub fn start(self) -> Self
pub fn start(self) -> Self
Starts the task context, including workers and the task cleaner.
Examples found in repository?
examples/basic.rs (line 21)
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = InMemoryTaskStore::new();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("name2".to_string(), 39), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}More examples
examples/nativedb.rs (line 26)
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = NativeDbTaskStore::default();
task_store.restore_tasks().await.unwrap();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.set_concurrency("default", 10)
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}Sourcepub async fn add_task<T>(
&self,
task: T,
delay_seconds: Option<u32>,
) -> Result<(), String>
pub async fn add_task<T>( &self, task: T, delay_seconds: Option<u32>, ) -> Result<(), String>
Adds a new task to the context for execution.
Examples found in repository?
examples/basic.rs (line 24)
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = InMemoryTaskStore::new();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("name2".to_string(), 39), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}More examples
examples/nativedb.rs (line 29)
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
tracing_subscriber::fmt()
.with_max_level(tracing::Level::INFO)
.init();
let task_store = NativeDbTaskStore::default();
task_store.restore_tasks().await.unwrap();
let context = TaskContext::new(task_store)
.register::<MyTask1>()
.register::<MyTask2>()
.set_concurrency("default", 10)
.start();
context
.add_task(MyTask1::new("name1".to_string(), 32), None)
.await
.unwrap();
context
.add_task(MyTask2::new("namexxxxxxx".to_string(), 3900), None)
.await
.unwrap();
tokio::time::sleep(Duration::from_secs(100000000)).await;
}Auto Trait Implementations
impl<S> Freeze for TaskContext<S>
impl<S> !RefUnwindSafe for TaskContext<S>
impl<S> Send for TaskContext<S>where
S: Sync,
impl<S> Sync for TaskContext<S>where
S: Sync,
impl<S> Unpin for TaskContext<S>
impl<S> !UnwindSafe for TaskContext<S>